@@ -127,6 +127,13 @@ static const CidConfig cid_ms_host_shutdown_config [MBIM_CID_MS_HOST_SHUTDOWN_LA
     { SET, NO_QUERY, NO_NOTIFY }, /* MBIM_CID_MS_HOST_SHUTDOWN_NOTIFY */
 };
 
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_MS_SAR_LAST MBIM_CID_MS_SAR_TRANSMISSION_STATUS
+static const CidConfig cid_ms_sar_config [MBIM_CID_MS_SAR_LAST] = {
+    { SET, QUERY, NOTIFY }, /* MBIM_CID_MS_SAR_CONFIG */
+    { SET, QUERY, NOTIFY }, /* MBIM_CID_MS_SAR_TRANSMISSION_STATUS */
+};
+
 /* Note: index of the array is CID-1 */
 #define MBIM_CID_PROXY_CONTROL_LAST MBIM_CID_PROXY_CONTROL_CONFIGURATION
 static const CidConfig cid_proxy_control_config [MBIM_CID_PROXY_CONTROL_LAST] = {
@@ -170,6 +177,31 @@ static const CidConfig cid_ms_basic_connect_extensions_config [MBIM_CID_MS_BASIC
     { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_DEVICE_RESET */
 };
 
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_QDU_LAST MBIM_CID_QDU_FILE_WRITE
+static const CidConfig cid_qdu_config [MBIM_CID_QDU_LAST] = {
+    { SET,    QUERY,    NOTIFY    }, /* MBIM_CID_QDU_UPDATE_SESSION */
+    { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_FILE_OPEN */
+    { SET,    NO_QUERY, NO_NOTIFY }, /* MBIM_CID_QDU_FILE_WRITE */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_LAST MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_RESET
+static const CidConfig cid_ms_uicc_low_level_access_config [MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_LAST] = {
+    { NO_SET,    QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_ATR */
+    { SET,    NO_QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_OPEN_CHANNEL */
+    { SET,    NO_QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_CLOSE_CHANNEL */
+    { SET,    NO_QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_APDU */
+    { SET,       QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_TERMINAL_CAPABILITY */
+    { SET,       QUERY,    NO_NOTIFY    }, /* MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_RESET */
+};
+
+/* Note: index of the array is CID-1 */
+#define MBIM_CID_QUECTEL_LAST MBIM_CID_QUECTEL_RADIO_STATE
+static const CidConfig cid_quectel_config [MBIM_CID_QUECTEL_LAST] = {
+    { NO_SET, QUERY, NO_NOTIFY }, /* MBIM_CID_QUECTEL_RADIO_STATE */
+};
+
 gboolean
 mbim_cid_can_set (MbimService service,
                   guint       cid)
@@ -199,6 +231,8 @@ mbim_cid_can_set (MbimService service,
         return cid_ms_firmware_id_config[cid - 1].set;
     case MBIM_SERVICE_MS_HOST_SHUTDOWN:
         return cid_ms_host_shutdown_config[cid - 1].set;
+    case MBIM_SERVICE_MS_SAR:
+        return cid_ms_sar_config[cid - 1].set;
     case MBIM_SERVICE_PROXY_CONTROL:
         return cid_proxy_control_config[cid - 1].set;
     case MBIM_SERVICE_QMI:
@@ -207,8 +241,14 @@ mbim_cid_can_set (MbimService service,
         return cid_atds_config[cid - 1].set;
     case MBIM_SERVICE_INTEL_FIRMWARE_UPDATE:
         return cid_intel_firmware_update_config[cid - 1].set;
+    case MBIM_SERVICE_QDU:
+        return cid_qdu_config[cid - 1].set;
     case MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS:
         return cid_ms_basic_connect_extensions_config[cid - 1].set;
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        return cid_ms_uicc_low_level_access_config[cid - 1].set;
+    case MBIM_SERVICE_QUECTEL:
+        return cid_quectel_config[cid - 1].set;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -246,6 +286,8 @@ mbim_cid_can_query (MbimService service,
         return cid_ms_firmware_id_config[cid - 1].query;
     case MBIM_SERVICE_MS_HOST_SHUTDOWN:
         return cid_ms_host_shutdown_config[cid - 1].query;
+    case MBIM_SERVICE_MS_SAR:
+        return cid_ms_sar_config[cid - 1].query;
     case MBIM_SERVICE_PROXY_CONTROL:
         return cid_proxy_control_config[cid - 1].query;
     case MBIM_SERVICE_QMI:
@@ -254,8 +296,14 @@ mbim_cid_can_query (MbimService service,
         return cid_atds_config[cid - 1].query;
     case MBIM_SERVICE_INTEL_FIRMWARE_UPDATE:
         return cid_intel_firmware_update_config[cid - 1].query;
+    case MBIM_SERVICE_QDU:
+        return cid_qdu_config[cid - 1].query;
     case MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS:
         return cid_ms_basic_connect_extensions_config[cid - 1].query;
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        return cid_ms_uicc_low_level_access_config[cid - 1].query;
+    case MBIM_SERVICE_QUECTEL:
+        return cid_quectel_config[cid - 1].query;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -293,6 +341,8 @@ mbim_cid_can_notify (MbimService service,
         return cid_ms_firmware_id_config[cid - 1].notify;
     case MBIM_SERVICE_MS_HOST_SHUTDOWN:
         return cid_ms_host_shutdown_config[cid - 1].notify;
+    case MBIM_SERVICE_MS_SAR:
+        return cid_ms_sar_config[cid - 1].notify;
     case MBIM_SERVICE_PROXY_CONTROL:
         return cid_proxy_control_config[cid - 1].notify;
     case MBIM_SERVICE_QMI:
@@ -301,8 +351,14 @@ mbim_cid_can_notify (MbimService service,
         return cid_atds_config[cid - 1].notify;
     case MBIM_SERVICE_INTEL_FIRMWARE_UPDATE:
         return cid_intel_firmware_update_config[cid - 1].notify;
+    case MBIM_SERVICE_QDU:
+        return cid_qdu_config[cid - 1].notify;
     case MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS:
         return cid_ms_basic_connect_extensions_config[cid - 1].notify;
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        return cid_ms_uicc_low_level_access_config[cid - 1].notify;
+    case MBIM_SERVICE_QUECTEL:
+        return cid_quectel_config[cid - 1].notify;
     case MBIM_SERVICE_INVALID:
     case MBIM_SERVICE_LAST:
     default:
@@ -341,6 +397,8 @@ mbim_cid_get_printable (MbimService service,
         return mbim_cid_ms_firmware_id_get_string (cid);
     case MBIM_SERVICE_MS_HOST_SHUTDOWN:
         return mbim_cid_ms_host_shutdown_get_string (cid);
+    case MBIM_SERVICE_MS_SAR:
+        return mbim_cid_ms_sar_get_string (cid);
     case MBIM_SERVICE_PROXY_CONTROL:
         return mbim_cid_proxy_control_get_string (cid);
     case MBIM_SERVICE_QMI:
@@ -349,8 +407,14 @@ mbim_cid_get_printable (MbimService service,
         return mbim_cid_atds_get_string (cid);
     case MBIM_SERVICE_INTEL_FIRMWARE_UPDATE:
         return mbim_cid_intel_firmware_update_get_string (cid);
+    case MBIM_SERVICE_QDU:
+        return mbim_cid_qdu_get_string (cid);
     case MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS:
         return mbim_cid_ms_basic_connect_extensions_get_string (cid);
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        return mbim_cid_ms_uicc_low_level_access_get_string (cid);
+    case MBIM_SERVICE_QUECTEL:
+        return mbim_cid_quectel_get_string (cid);
     case MBIM_SERVICE_LAST:
     default:
         g_assert_not_reached ();
