@@ -41,10 +41,6 @@
 #define OPEN_RETRY_TIMEOUT_SECS 5
 #define OPEN_CLOSE_TIMEOUT_SECS 2
 
-#if defined WITH_UDEV
-# include <gudev/gudev.h>
-#endif
-
 #include "mbim-common.h"
 #include "mbim-utils.h"
 #include "mbim-device.h"
@@ -52,8 +48,10 @@
 #include "mbim-message-private.h"
 #include "mbim-error-types.h"
 #include "mbim-enum-types.h"
+#include "mbim-helpers.h"
 #include "mbim-proxy.h"
 #include "mbim-proxy-control.h"
+#include "mbim-net-port-manager.h"
 
 static void async_initable_iface_init (GAsyncInitableIface *iface);
 
@@ -98,6 +96,9 @@ struct _MbimDevicePrivate {
     gchar *path;
     gchar *path_display;
 
+    /* WWAN interface */
+    gchar *wwan_iface;
+
     /* I/O channel, set when the file is open */
     GIOChannel *iochannel;
     GSource *iochannel_source;
@@ -123,6 +124,9 @@ struct _MbimDevicePrivate {
 
     /* message size */
     guint16 max_control_transfer;
+
+    /* Link management */
+    MbimNetPortManager *net_port_manager;
 };
 
 #define MAX_SPAWN_RETRIES             10
@@ -444,6 +448,320 @@ mbim_device_is_open (MbimDevice *self)
     return (self->priv->open_status == OPEN_STATUS_OPEN);
 }
 
+/*****************************************************************************/
+
+static void
+reload_wwan_iface_name (MbimDevice *self)
+{
+    g_autofree gchar   *cdc_wdm_device_name = NULL;
+    guint               i;
+    g_autoptr(GError)   error = NULL;
+    static const gchar *driver_names[] = { "usbmisc", /* kernel >= 3.6 */
+                                           "usb" };   /* kernel < 3.6 */
+
+    g_clear_pointer (&self->priv->wwan_iface, g_free);
+
+    cdc_wdm_device_name = mbim_helpers_get_devname (self->priv->path, &error);
+    if (!cdc_wdm_device_name) {
+        g_warning ("[%s] invalid path for cdc-wdm control port: %s",
+                   self->priv->path_display,
+                   error->message);
+        return;
+    }
+
+    for (i = 0; i < G_N_ELEMENTS (driver_names) && !self->priv->wwan_iface; i++) {
+        g_autofree gchar           *sysfs_path = NULL;
+        g_autoptr(GFile)            sysfs_file = NULL;
+        g_autoptr(GFileEnumerator)  enumerator = NULL;
+        GFileInfo                  *file_info  = NULL;
+
+        /* WWAN iface name loading only applicable for cdc_mbim driver right now
+         * (so MBIM port exposed by the cdc-wdm driver in the usbmisc subsystem),
+         * not for any other subsystem or driver */
+        sysfs_path = g_strdup_printf ("/sys/class/%s/%s/device/net/", driver_names[i], cdc_wdm_device_name);
+        sysfs_file = g_file_new_for_path (sysfs_path);
+        enumerator = g_file_enumerate_children (sysfs_file,
+                                                G_FILE_ATTRIBUTE_STANDARD_NAME,
+                                                G_FILE_QUERY_INFO_NONE,
+                                                NULL,
+                                                NULL);
+        if (!enumerator)
+            continue;
+
+        /* Ignore errors when enumerating */
+        while ((file_info = g_file_enumerator_next_file (enumerator, NULL, NULL)) != NULL) {
+            const gchar *name;
+
+            name = g_file_info_get_name (file_info);
+            if (name) {
+                /* We only expect ONE file in the sysfs directory corresponding
+                 * to this control port, if more found for any reason, warn about it */
+                if (self->priv->wwan_iface)
+                    g_warning ("[%s] invalid additional wwan iface found: %s",
+                               self->priv->path_display, name);
+                else
+                    self->priv->wwan_iface = g_strdup (name);
+            }
+            g_object_unref (file_info);
+        }
+        if (!self->priv->wwan_iface)
+            g_warning ("[%s] wwan iface not found", self->priv->path_display);
+    }
+
+    /* wwan_iface won't be set at this point if the kernel driver in use isn't in
+     * the usbmisc subsystem */
+}
+
+static gboolean
+setup_net_port_manager (MbimDevice  *self,
+                        GError    **error)
+{
+    /* If we have a valid one already, use that one */
+    if (self->priv->net_port_manager)
+        return TRUE;
+
+    /* For now we only support link management with cdc-mbim */
+    reload_wwan_iface_name (self);
+    if (!self->priv->wwan_iface) {
+        g_set_error (error, MBIM_CORE_ERROR, MBIM_CORE_ERROR_UNSUPPORTED,
+                     "Link management is unsupported");
+        return FALSE;
+    }
+
+    self->priv->net_port_manager = mbim_net_port_manager_new (self->priv->wwan_iface, error);
+    return !!self->priv->net_port_manager;
+}
+
+/*****************************************************************************/
+/* Link management */
+
+typedef struct {
+    guint  session_id;
+    gchar *ifname;
+} AddLinkResult;
+
+static void
+add_link_result_free (AddLinkResult *ctx)
+{
+    g_free (ctx->ifname);
+    g_free (ctx);
+}
+
+gchar *
+mbim_device_add_link_finish (MbimDevice    *self,
+                             GAsyncResult  *res,
+                             guint         *session_id,
+                             GError       **error)
+{
+    AddLinkResult *ctx;
+    gchar         *ifname;
+
+    ctx = g_task_propagate_pointer (G_TASK (res), error);
+    if (!ctx)
+        return NULL;
+
+    if (session_id)
+        *session_id = ctx->session_id;
+
+    ifname = g_steal_pointer (&ctx->ifname);
+    add_link_result_free (ctx);
+    return ifname;
+}
+
+static void
+device_add_link_ready (MbimNetPortManager *net_port_manager,
+                       GAsyncResult      *res,
+                       GTask             *task)
+{
+    GError        *error = NULL;
+    AddLinkResult *ctx;
+
+    ctx = g_new0 (AddLinkResult, 1);
+    ctx->ifname = mbim_net_port_manager_add_link_finish (net_port_manager, &ctx->session_id, res, &error);
+
+    if (!ctx->ifname) {
+        g_prefix_error (&error, "Could not allocate link: ");
+        g_task_return_error (task, error);
+        add_link_result_free (ctx);
+    } else
+        g_task_return_pointer (task, ctx, (GDestroyNotify) add_link_result_free);
+
+    g_object_unref (task);
+}
+
+void
+mbim_device_add_link (MbimDevice          *self,
+                      guint                session_id,
+                      const gchar         *base_ifname,
+                      const gchar         *ifname_prefix,
+                      GCancellable        *cancellable,
+                      GAsyncReadyCallback  callback,
+                      gpointer             user_data)
+{
+    GTask  *task;
+    GError *error = NULL;
+
+    g_return_if_fail (MBIM_IS_DEVICE (self));
+    g_return_if_fail (base_ifname);
+    g_return_if_fail ((session_id <= MBIM_DEVICE_SESSION_ID_MAX) || (session_id == MBIM_DEVICE_SESSION_ID_AUTOMATIC));
+
+    task = g_task_new (self, cancellable, callback, user_data);
+
+    if (!setup_net_port_manager (self, &error)) {
+        g_task_return_error (task, error);
+        g_object_unref (task);
+        return;
+    }
+
+    g_assert (self->priv->net_port_manager);
+    mbim_net_port_manager_add_link (self->priv->net_port_manager,
+                                    session_id,
+                                    base_ifname,
+                                    ifname_prefix,
+                                    5,
+                                    cancellable,
+                                    (GAsyncReadyCallback) device_add_link_ready,
+                                    task);
+}
+
+gboolean
+mbim_device_delete_link_finish (MbimDevice    *self,
+                                GAsyncResult  *res,
+                                GError       **error)
+{
+    return g_task_propagate_boolean (G_TASK (res), error);
+}
+
+static void
+device_del_link_ready (MbimNetPortManager *net_port_manager,
+                       GAsyncResult       *res,
+                       GTask              *task)
+{
+    GError *error = NULL;
+
+    if (!mbim_net_port_manager_del_link_finish (net_port_manager, res, &error))
+        g_task_return_error (task, error);
+    else
+        g_task_return_boolean (task, TRUE);
+    g_object_unref (task);
+}
+
+void
+mbim_device_delete_link (MbimDevice          *self,
+                         const gchar         *ifname,
+                         GCancellable        *cancellable,
+                         GAsyncReadyCallback  callback,
+                         gpointer             user_data)
+{
+    GTask  *task;
+    GError *error = NULL;
+
+    g_return_if_fail (MBIM_IS_DEVICE (self));
+    g_return_if_fail (ifname);
+
+    task = g_task_new (self, cancellable, callback, user_data);
+
+    if (!setup_net_port_manager (self, &error)) {
+        g_task_return_error (task, error);
+        g_object_unref (task);
+        return;
+    }
+
+    g_assert (self->priv->net_port_manager);
+    mbim_net_port_manager_del_link (self->priv->net_port_manager,
+                                   ifname,
+                                    5, /* timeout */
+                                    cancellable,
+                                    (GAsyncReadyCallback) device_del_link_ready,
+                                    task);
+}
+
+/*****************************************************************************/
+
+gboolean
+mbim_device_delete_all_links_finish (MbimDevice    *self,
+                                     GAsyncResult  *res,
+                                     GError       **error)
+{
+    return g_task_propagate_boolean (G_TASK (res), error);
+}
+
+static void
+device_del_all_links_ready (MbimNetPortManager *net_port_manager,
+                            GAsyncResult       *res,
+                            GTask              *task)
+{
+    GError *error = NULL;
+
+    if (!mbim_net_port_manager_del_all_links_finish (net_port_manager, res, &error))
+        g_task_return_error (task, error);
+    else
+        g_task_return_boolean (task, TRUE);
+    g_object_unref (task);
+}
+
+void
+mbim_device_delete_all_links (MbimDevice          *self,
+                              const gchar         *base_ifname,
+                              GCancellable        *cancellable,
+                              GAsyncReadyCallback  callback,
+                              gpointer             user_data)
+{
+    GTask  *task;
+    GError *error = NULL;
+
+    g_return_if_fail (MBIM_IS_DEVICE (self));
+    g_return_if_fail (base_ifname);
+
+    task = g_task_new (self, cancellable, callback, user_data);
+
+    if (!setup_net_port_manager (self, &error)) {
+        g_task_return_error (task, error);
+        g_object_unref (task);
+        return;
+    }
+
+    g_assert (self->priv->net_port_manager);
+    mbim_net_port_manager_del_all_links (self->priv->net_port_manager,
+                                         base_ifname,
+                                         cancellable,
+                                         (GAsyncReadyCallback) device_del_all_links_ready,
+                                         task);
+}
+
+/*****************************************************************************/
+
+gboolean
+mbim_device_list_links (MbimDevice   *self,
+                        const gchar  *base_ifname,
+                        GPtrArray   **out_links,
+                        GError      **error)
+{
+    g_return_val_if_fail (MBIM_IS_DEVICE (self), FALSE);
+    g_return_val_if_fail (base_ifname, FALSE);
+
+    if (!setup_net_port_manager (self, error))
+        return FALSE;
+
+    g_assert (self->priv->net_port_manager);
+    return mbim_net_port_manager_list_links (self->priv->net_port_manager,
+                                             base_ifname,
+                                             out_links,
+                                             error);
+}
+
+/*****************************************************************************/
+
+gboolean
+mbim_device_check_link_supported (MbimDevice  *self,
+                                  GError     **error)
+{
+    g_return_val_if_fail (MBIM_IS_DEVICE (self), FALSE);
+
+    /* if we can setup a net port manager, link management is supported */
+    return setup_net_port_manager (self, error);
+}
+
 /*****************************************************************************/
 /* Open device */
 
@@ -827,90 +1145,6 @@ struct usb_cdc_mbim_desc {
     guint8  bmNetworkCapabilities;
 } __attribute__ ((packed));
 
-#if defined WITH_UDEV
-
-static gchar *
-get_descriptors_filepath (MbimDevice *self)
-{
-    GUdevClient       *client;
-    GUdevDevice       *device = NULL;
-    GUdevDevice       *parent_device = NULL;
-    GUdevDevice       *grandparent_device = NULL;
-    g_autofree gchar  *descriptors_path = NULL;
-    g_autofree gchar  *device_basename = NULL;
-    g_autoptr(GError)  error = NULL;
-
-    client = g_udev_client_new (NULL);
-    if (!G_UDEV_IS_CLIENT (client)) {
-        g_warning ("[%s] Couldn't get udev client",
-                   self->priv->path_display);
-        goto out;
-    }
-
-    /* We need to get the sysfs of the cdc-wdm's grandfather:
-     *
-     *   * Device's sysfs path is like:
-     *      /sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:2.0/usbmisc/cdc-wdm0
-     *   * Parent's sysfs path is like:
-     *      /sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:2.0
-     *   * Grandparent's sysfs path is like:
-     *      /sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5
-     *
-     *   Which is the one with the descriptors file.
-     */
-
-    device_basename = __mbim_utils_get_devname (self->priv->path, &error);
-    if (!device_basename) {
-        g_warning ("[%s] Invalid path for cdc-wdm control port: %s",
-                   self->priv->path_display, error->message);
-        goto out;
-    }
-
-    device = g_udev_client_query_by_subsystem_and_name (client, "usb", device_basename);
-    if (!device) {
-        device = g_udev_client_query_by_subsystem_and_name (client, "usbmisc", device_basename);
-        if (!device) {
-            /* possibly using a different driver instead of cdc_mbim */
-            g_debug ("[%s] Couldn't find udev device in usb/usbmisc subsystems",
-                     self->priv->path_display);
-            goto out;
-        }
-    }
-
-    parent_device = g_udev_device_get_parent (device);
-    if (!parent_device) {
-        g_warning ("[%s] Couldn't find parent udev device",
-                   self->priv->path_display);
-        goto out;
-    }
-
-    grandparent_device = g_udev_device_get_parent (parent_device);
-    if (!grandparent_device) {
-        g_warning ("[%s] Couldn't find grandparent udev device",
-                   self->priv->path_display);
-        goto out;
-    }
-
-    descriptors_path = g_build_path (G_DIR_SEPARATOR_S,
-                                     g_udev_device_get_sysfs_path (grandparent_device),
-                                     "descriptors",
-                                     NULL);
-
-out:
-    if (parent_device)
-        g_object_unref (parent_device);
-    if (grandparent_device)
-        g_object_unref (grandparent_device);
-    if (device)
-        g_object_unref (device);
-    if (client)
-        g_object_unref (client);
-
-    return g_steal_pointer (&descriptors_path);
-}
-
-#else
-
 static gchar *
 get_descriptors_filepath (MbimDevice *self)
 {
@@ -952,8 +1186,6 @@ get_descriptors_filepath (MbimDevice *self)
     return g_steal_pointer (&descriptors_path);
 }
 
-#endif
-
 static guint16
 read_max_control_transfer (MbimDevice *self)
 {
@@ -1873,53 +2105,46 @@ device_send (MbimDevice   *self,
 
     fragments = _mbim_message_split_fragments (message, MAX_CONTROL_TRANSFER, &n_fragments);
     for (i = 0; i < n_fragments; i++) {
-        if (mbim_utils_get_traces_enabled ()) {
-            g_autoptr(GByteArray)  bytearray = NULL;
-            g_autofree gchar      *printable = NULL;
-            g_autofree gchar      *printable_h = NULL;
-            g_autofree gchar      *printable_fh = NULL;
-            g_autofree gchar      *printable_d = NULL;
+        g_autoptr(GByteArray)  full_fragment = NULL;
+        g_autofree gchar      *printable_headers = NULL;
 
-            printable_h  = mbim_common_str_hex (&fragments[i].header, sizeof (fragments[i].header), ':');
-            printable_fh = mbim_common_str_hex (&fragments[i].fragment_header, sizeof (fragments[i].fragment_header), ':');
-            printable_d  = mbim_common_str_hex (fragments[i].data, fragments[i].data_length, ':');
+        /* Build compiled fragment headers */
+        full_fragment = g_byte_array_new ();
+        g_byte_array_append (full_fragment, (guint8 *)&fragments[i].header, sizeof (fragments[i].header));
+        g_byte_array_append (full_fragment, (guint8 *)&fragments[i].fragment_header, sizeof (fragments[i].fragment_header));
+
+        /* Build dummy message with only headers for printable purposes only */
+        if (mbim_utils_get_traces_enabled ())
+            printable_headers = mbim_message_get_printable ((MbimMessage *)full_fragment, "<<<<<< ", TRUE);
+
+        /* Append the actual fragment data */
+        g_byte_array_append (full_fragment, (guint8 *)fragments[i].data, fragments[i].data_length);
+
+        if (mbim_utils_get_traces_enabled ()) {
+            g_autofree gchar *printable_full = NULL;
+
+            printable_full  = mbim_common_str_hex ((const guint8 *)full_fragment->data, full_fragment->len, ':');
             g_debug ("[%s] Sent fragment (%u)...\n"
                      "<<<<<< RAW:\n"
                      "<<<<<<   length = %u\n"
-                     "<<<<<<   data   = %s%s%s\n",
+                     "<<<<<<   data   = %s\n",
                      self->priv->path_display, i,
-                     (guint)(sizeof (fragments[i].header) +
-                             sizeof (fragments[i].fragment_header) +
-                             fragments[i].data_length),
-                     printable_h, printable_fh, printable_d);
+                     full_fragment->len,
+                     printable_full);
 
-            /* Dummy message for printable purposes only */
-            bytearray = g_byte_array_new ();
-            g_byte_array_append (bytearray, (guint8 *)&fragments[i].header, sizeof (fragments[i].header));
-            g_byte_array_append (bytearray, (guint8 *)&fragments[i].fragment_header, sizeof (fragments[i].fragment_header));
-            printable = mbim_message_get_printable ((MbimMessage *)bytearray, "<<<<<< ", TRUE);
             g_debug ("[%s] Sent fragment (translated)...\n%s",
                      self->priv->path_display,
-                     printable);
+                     printable_headers);
         }
 
-        /* Write fragment headers */
+        /* Write whole packet to MBIM device.
+         * Here send whole packet rather than seperated elements, such as header,
+         * fragment_header, data, because some MBIM devices may have errors on
+         * seperated fragment case, such as "MBIM protocol error: LengthMismatch"
+         */
         if (!device_write (self,
-                           (guint8 *)&fragments[i].header,
-                           sizeof (fragments[i].header),
-                           error))
-            return FALSE;
-
-        if (!device_write (self,
-                           (guint8 *)&fragments[i].fragment_header,
-                           sizeof (fragments[i].fragment_header),
-                           error))
-            return FALSE;
-
-        /* Write fragment data */
-        if (!device_write (self,
-                           fragments[i].data,
-                           fragments[i].data_length,
+                           (guint8 *)full_fragment->data,
+                           full_fragment->len,
                            error))
             return FALSE;
     }
@@ -2235,6 +2460,7 @@ dispose (GObject *object)
     g_clear_object (&self->priv->file);
 
     destroy_iochannel (self, NULL);
+    g_clear_object (&self->priv->net_port_manager);
 
     G_OBJECT_CLASS (mbim_device_parent_class)->dispose (object);
 }
@@ -2257,6 +2483,7 @@ finalize (GObject *object)
 
     g_free (self->priv->path);
     g_free (self->priv->path_display);
+    g_free (self->priv->wwan_iface);
 
     G_OBJECT_CLASS (mbim_device_parent_class)->finalize (object);
 }
