@@ -1088,6 +1088,91 @@ typedef enum { /*< since=1.4 >*/
     MBIM_DSS_LINK_STATE_ACTIVATE   = 1
 } MbimDssLinkState;
 
+/*****************************************************************************/
+/* 'QDU update session' enums */
+
+/**
+ * MbimQduSessionAction:
+ * @MBIM_QDU_SESSION_ACTION_START: Start.
+ * @MBIM_QDU_SESSION_ACTION_STOP: Stop.
+ *
+ * Action performed for the session initialization.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_QDU_SESSION_ACTION_START = 0,
+    MBIM_QDU_SESSION_ACTION_STOP  = 1,
+} MbimQduSessionAction;
+
+/*****************************************************************************/
+/* 'QDU session type' enums */
+
+/**
+ * MbimQduSessionType:
+ * @MBIM_QDU_SESSION_TYPE_NONE: No update session.
+ * @MBIM_QDU_SESSION_TYPE_LE: LE-based update procedure.
+ *
+ * QDU session types.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_QDU_SESSION_TYPE_NONE = 0,
+    MBIM_QDU_SESSION_TYPE_LE   = 1,
+} MbimQduSessionType;
+
+/*****************************************************************************/
+/* 'QDU session status' enums */
+
+/**
+ * MbimQduSessionStatus:
+ * @MBIM_QDU_SESSION_STATUS_INACTIVE: Update session is not active.
+ * @MBIM_QDU_SESSION_STATUS_FILE_TRANSFER: Updated files are being transferred from host to function or function is waiting host to send updated files.
+ * @MBIM_QDU_SESSION_STATUS_APPLY_UPDATE: The function is applying the update package.
+ *
+ * QDU session status.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_QDU_SESSION_STATUS_INACTIVE      = 0,
+    MBIM_QDU_SESSION_STATUS_FILE_TRANSFER = 1,
+    MBIM_QDU_SESSION_STATUS_APPLY_UPDATE  = 2,
+} MbimQduSessionStatus;
+
+/*****************************************************************************/
+/* 'QDU session result' enums */
+
+/**
+ * MbimQduSessionResult:
+ * @MBIM_QDU_SESSION_RESULT_SUCCESS: Success
+ * @MBIM_QDU_SESSION_RESULT_FAILURE: Failure
+ *
+ * QDU session result.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_QDU_SESSION_RESULT_SUCCESS = 0,
+    MBIM_QDU_SESSION_RESULT_FAILURE = 1,
+} MbimQduSessionResult;
+
+/*****************************************************************************/
+/* 'QDU file type' enums */
+
+/**
+ * MbimQduFileType:
+ * @MBIM_QDU_FILE_TYPE_LITTLE_ENDIAN_PACKAGE: LE Package
+ *
+ * QDU session result.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_QDU_FILE_TYPE_LITTLE_ENDIAN_PACKAGE = 0,
+} MbimQduFileType;
+
 /*****************************************************************************/
 /* 'ATDS RAT' enums */
 
@@ -1123,9 +1208,9 @@ typedef enum { /*< since=1.16 >*/
  * Since: 1.16
  */
 typedef enum { /*< since=1.16 >*/
-    MBIM_ATDS_PROVIDER_PLMN_MODE_GSM = 0,
+    MBIM_ATDS_PROVIDER_PLMN_MODE_GSM   = 0,
     MBIM_ATDS_PROVIDER_PLMN_MODE_UTRAN = 6,
-    MBIM_ATDS_PROVIDER_PLMN_MODE_LTE = 7,
+    MBIM_ATDS_PROVIDER_PLMN_MODE_LTE   = 7,
 } MbimAtdsProviderPlmnMode;
 
 /*****************************************************************************/
@@ -1212,6 +1297,191 @@ typedef enum { /*< since=1.18 >*/
     MBIM_LTE_ATTACH_STATE_ATTACHED = 1
 } MbimLteAttachState;
 
+/*****************************************************************************/
+/* 'SAR config' enums */
+
+/**
+ * MbimSarControlMode:
+ * @MBIM_SAR_CONTROL_MODE_DEVICE: SAR backoff is controlled by the modem directly.
+ * @MBIM_SAR_CONTROL_MODE_OS: SAR backoff is controlled by the host operating system.
+ *
+ * SAR backoff mechanism control modes.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_SAR_CONTROL_MODE_DEVICE = 0,
+    MBIM_SAR_CONTROL_MODE_OS     = 1
+} MbimSarControlMode;
+
+/**
+ * MbimSarBackoffState:
+ * @MBIM_SAR_BACKOFF_STATE_DISABLED: SAR backoff is disabled.
+ * @MBIM_SAR_BACKOFF_STATE_ENABLED: SAR backoff is enabled.
+ *
+ * SAR backoff state.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_SAR_BACKOFF_STATE_DISABLED = 0,
+    MBIM_SAR_BACKOFF_STATE_ENABLED  = 1
+} MbimSarBackoffState;
+
+/**
+ * MbimSarWifiHardwareState:
+ * @MBIM_SAR_WIFI_HARDWARE_STATE_INTEGRATED: Integrated.
+ * @MBIM_SAR_WIFI_HARDWARE_STATE_NOT_INTEGRATED: Not integrated.
+ *
+ * Whether the Wi-Fi and cellular SAR are integrated at hardware level.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_SAR_WIFI_HARDWARE_STATE_INTEGRATED     = 0,
+    MBIM_SAR_WIFI_HARDWARE_STATE_NOT_INTEGRATED = 1
+} MbimSarWifiHardwareState;
+
+/**
+ * MbimTransmissionNotificationStatus:
+ * @MBIM_TRANSMISSION_NOTIFICATION_STATUS_DISABLED: Notification disabled.
+ * @MBIM_TRANSMISSION_NOTIFICATION_STATUS_ENABLED: Notification enabled.
+ *
+ * Whether modem channel transmission status notification is disabled or enabled.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_TRANSMISSION_NOTIFICATION_STATUS_DISABLED = 0,
+    MBIM_TRANSMISSION_NOTIFICATION_STATUS_ENABLED  = 1
+} MbimTransmissionNotificationStatus;
+
+/**
+ * MbimTransmissionState:
+ * @MBIM_TRANSMISSION_STATE_INACTIVE: Modem was not actively transmitting data.
+ * @MBIM_TRANSMISSION_STATE_ACTIVE: Modem was actively transmitting data.
+ *
+ * Whether modem is having TX traffic every hysteresis timeout.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_TRANSMISSION_STATE_INACTIVE = 0,
+    MBIM_TRANSMISSION_STATE_ACTIVE   = 1
+} MbimTransmissionState;
+
+/*****************************************************************************/
+/* 'Slot Info Status' enums */
+
+/**
+ * MbimUiccSlotState:
+ * @MBIM_UICC_SLOT_STATE_UNKNOWN: The modem is still in the process of initializing so the SIM slot state is not deterministic.
+ * @MBIM_UICC_SLOT_SATE_OFF_EMPTY: The UICC slot is powered off and no card is present.
+ * @MBIM_UICC_SLOT_STATE_OFF: The UICC slot is powered off.
+ * @MBIM_UICC_SLOT_STATE_EMPTY: The UICC slot is empty(there is no card in it).
+ * @MBIM_UICC_SLOT_STATE_NOT_READY: The UICC slot is occupied and powered on but the card within it is not yet ready.
+ * @MBIM_UICC_SLOT_STATE_ACTIVE: The UICC slot is occupied and the card within it is ready.
+ * @MBIM_UICC_SLOT_STATE_ERROR: The UICC slot is occupied and powreed on but the card is in an error state and cannot be used until it is next reset.
+ * @MBIM_UICC_SLOT_STATE_ACTIVE_ESIM: The card in the slot is an eSIM with an active profile and is ready to accept commands.
+ * @MBIM_UICC_SLOT_STATE_ACTIVE_ESIM_NO_PROFILES: The card in the slot is an eSIM with no profiles(or no active profiles) and is ready to accept commands.
+ *
+ * MbimUiccSlotState
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_UICC_SLOT_STATE_UNKNOWN = 0,
+    MBIM_UICC_SLOT_SATE_OFF_EMPTY = 1,
+    MBIM_UICC_SLOT_STATE_OFF = 2,
+    MBIM_UICC_SLOT_STATE_EMPTY = 3,
+    MBIM_UICC_SLOT_STATE_NOT_READY = 4,
+    MBIM_UICC_SLOT_STATE_ACTIVE = 5,
+    MBIM_UICC_SLOT_STATE_ERROR = 6,
+    MBIM_UICC_SLOT_STATE_ACTIVE_ESIM = 7,
+    MBIM_UICC_SLOT_STATE_ACTIVE_ESIM_NO_PROFILES = 8
+} MbimUiccSlotState;
+
+/*****************************************************************************/
+/* 'UICC APDU' enums */
+
+/**
+ * MbimUiccSecureMessaging:
+ * @MBIM_UICC_SECURE_MESSAGING_NONE: No secure messaging.
+ * @MBIM_UICC_SECURE_MESSAGING_NO_HDR_AUTH: Secure, command header not authenticated.
+ *
+ * Specifies whether apdu is exchanged using secure messaging.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_UICC_SECURE_MESSAGING_NONE             = 0,
+    MBIM_UICC_SECURE_MESSAGING_NO_HDR_AUTH      = 1,
+} MbimUiccSecureMessaging;
+
+/**
+ * MbimUiccClassByteType:
+ * @MBIM_UICC_CLASS_BYTE_TYPE_INTER_INDUSTRY: Defined according to first interindustry definition in ISO 7816-4.
+ * @MBIM_UICC_CLASS_BYTE_TYPE_EXTENDED: Defined according to extended definition in ETSI 102 221.
+ *
+ * Specifies the type of class byte definition.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_UICC_CLASS_BYTE_TYPE_INTER_INDUSTRY   = 0,
+    MBIM_UICC_CLASS_BYTE_TYPE_EXTENDED         = 1,
+} MbimUiccClassByteType;
+
+/* 'UICC Reset' enums */
+
+/**
+ * MbimUiccPassThroughAction:
+ * @MBIM_UICC_PASS_THROUGH_ACTION_DISABLE: Disable pass through.
+ * @MBIM_UICC_PASS_THROUGH_ACTION_ENABLE: Enable pass through.
+ *
+ * Pass through actions host can specify to modem. Upon reset
+ * treats UICC as if pass through or as a regular UICC
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_UICC_PASS_THROUGH_ACTION_DISABLE     = 0,
+    MBIM_UICC_PASS_THROUGH_ACTION_ENABLE      = 1,
+} MbimUiccPassThroughAction;
+
+/**
+ * MbimUiccPassThroughStatus:
+ * @MBIM_UICC_PASS_THROUGH_STATUS_DISABLED: Pass through disabled.
+ * @MBIM_UICC_PASS_THROUGH_STATUS_ENABLED: Pass through enabled.
+ *
+ * Pass through status of the modem specifies to the host.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    MBIM_UICC_PASS_THROUGH_STATUS_DISABLED   = 0,
+    MBIM_UICC_PASS_THROUGH_STATUS_ENABLED    = 1,
+} MbimUiccPassThroughStatus;
+
+/*****************************************************************************/
+/* 'Quectel Radio State' enums */
+
+/**
+ * MbimQuectelRadioSwitchState:
+ * @MBIM_QUECTEL_RADIO_SWITCH_STATE_OFF: Radio is off.
+ * @MBIM_QUECTEL_RADIO_SWITCH_STATE_ON: Radio is on.
+ * @MBIM_QUECTEL_RADIO_SWITCH_STATE_FCC_LOCKED: Radio is FCC locked.
+ *
+ * Radio switch state.
+ *
+ * Since: 1.26.2
+ */
+typedef enum { /*< since=1.26.2 >*/
+    MBIM_QUECTEL_RADIO_SWITCH_STATE_OFF        = 0,
+    MBIM_QUECTEL_RADIO_SWITCH_STATE_ON         = 1,
+    MBIM_QUECTEL_RADIO_SWITCH_STATE_FCC_LOCKED = 4,
+} MbimQuectelRadioSwitchState;
+
 G_END_DECLS
 
 #endif /* _LIBMBIM_GLIB_MBIM_ENUMS_H_ */
