@@ -122,6 +122,10 @@ gboolean mbim_uuid_from_printable (const gchar *str,
  * @MBIM_SERVICE_ATDS: ATT Device service. Since 1.16.
  * @MBIM_SERVICE_INTEL_FIRMWARE_UPDATE: Intel firmware update service. Since 1.16.
  * @MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS: Microsoft basic connectivity extensions service. Since 1.18.
+ * @MBIM_SERVICE_MS_SAR: Microsoft SAR service. Since 1.26.
+ * @MBIM_SERVICE_QDU: QDU firmware update service. Since 1.26.
+ * @MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS: Microsoft UICC Low Level Access service. Since 1.26.
+ * @MBIM_SERVICE_QUECTEL: Quectel specific operations. Since 1.26.2.
  * @MBIM_SERVICE_LAST: Internal value.
  *
  * Enumeration of the generic MBIM services.
@@ -144,6 +148,10 @@ typedef enum { /*< since=1.0 >*/
     MBIM_SERVICE_ATDS                        = 12,
     MBIM_SERVICE_INTEL_FIRMWARE_UPDATE       = 13,
     MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS = 14,
+    MBIM_SERVICE_MS_SAR                      = 15,
+    MBIM_SERVICE_QDU                         = 16,
+    MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS    = 17,
+    MBIM_SERVICE_QUECTEL                     = 18,
 #if defined LIBMBIM_GLIB_COMPILATION
     MBIM_SERVICE_LAST /*< skip >*/
 #endif
@@ -259,6 +267,17 @@ typedef enum { /*< since=1.0 >*/
  */
 #define MBIM_UUID_MS_HOST_SHUTDOWN mbim_uuid_from_service (MBIM_SERVICE_MS_HOST_SHUTDOWN)
 
+/**
+ * MBIM_UUID_MS_SAR:
+ *
+ * Get the UUID of the %MBIM_SERVICE_MS_SAR service.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.26
+ */
+#define MBIM_UUID_MS_SAR mbim_uuid_from_service (MBIM_SERVICE_MS_SAR)
+
 /**
  * MBIM_UUID_PROXY_CONTROL:
  *
@@ -303,6 +322,17 @@ typedef enum { /*< since=1.0 >*/
  */
 #define MBIM_UUID_INTEL_FIRMWARE_UPDATE mbim_uuid_from_service (MBIM_SERVICE_INTEL_FIRMWARE_UPDATE)
 
+/**
+ * MBIM_UUID_QDU:
+ *
+ * Get the UUID of the %MBIM_SERVICE_QDU service.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.26
+ */
+#define MBIM_UUID_QDU mbim_uuid_from_service (MBIM_SERVICE_QDU)
+
 /**
  * MBIM_UUID_MS_BASIC_CONNECT_EXTENSIONS:
  *
@@ -314,6 +344,17 @@ typedef enum { /*< since=1.0 >*/
  */
 #define MBIM_UUID_MS_BASIC_CONNECT_EXTENSIONS mbim_uuid_from_service (MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS)
 
+/**
+ * MBIM_UUID_QUECTEL:
+ *
+ * Get the UUID of the %MBIM_SERVICE_QUECTEL service.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ *
+ * Since: 1.26.2
+ */
+#define MBIM_UUID_QUECTEL mbim_uuid_from_service (MBIM_SERVICE_QUECTEL)
+
 /**
  * mbim_service_lookup_name:
  * @service: a MbimService or custom service.
@@ -450,6 +491,15 @@ const MbimUuid *mbim_uuid_from_context_type (MbimContextType context_type);
  */
 MbimContextType mbim_uuid_to_context_type (const MbimUuid *uuid);
 
+/**
+ * MBIM_UUID_MS_UICC_LOW_LEVEL_ACCESS:
+ *
+ * Get the UUID of the %MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS service.
+ *
+ * Returns: (transfer none): a #MbimUuid.
+ */
+#define MBIM_UUID_MS_UICC_LOW_LEVEL_ACCESS mbim_uuid_from_service (MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS)
+
 G_END_DECLS
 
 #endif /* _LIBMBIM_GLIB_MBIM_UUID_H_ */
