@@ -20,7 +20,7 @@
 #include "mbim-message-private.h"
 #include "mbim-cid.h"
 #include "mbim-enums.h"
-#include "mbim-utils.h"
+#include "mbim-common.h"
 #include "mbim-basic-connect.h"
 #include "mbim-ussd.h"
 #include "mbim-auth.h"
@@ -38,8 +38,8 @@ test_message_trace (const guint8 *computed,
     gchar *message_str;
     gchar *expected_str;
 
-    message_str = __mbim_utils_str_hex (computed, computed_size, ':');
-    expected_str = __mbim_utils_str_hex (expected, expected_size, ':');
+    message_str = mbim_common_str_hex (computed, computed_size, ':');
+    expected_str = mbim_common_str_hex (expected, expected_size, ':');
 
     /* Dump all message contents */
     g_print ("\n"
