@@ -1783,6 +1783,79 @@ test_message_parser_basic_connect_connect_short (void)
     g_assert (error != NULL);
 }
 
+static void
+test_message_parser_basic_connect_visible_providers_overflow (void)
+{
+    guint32 n_providers;
+    g_autoptr(GError) error = NULL;
+    g_autoptr(MbimProviderArray) providers = NULL;
+    g_autoptr(MbimMessage) response = NULL;
+    gboolean result;
+
+    const guint8 buffer [] =  {
+        /* header */
+        0x03, 0x00, 0x00, 0x80, /* type */
+        0xB4, 0x00, 0x00, 0x00, /* length */
+        0x02, 0x00, 0x00, 0x00, /* transaction id */
+        /* fragment header */
+        0x01, 0x00, 0x00, 0x00, /* total */
+        0x00, 0x00, 0x00, 0x00, /* current */
+        /* command_done_message */
+        0xA2, 0x89, 0xCC, 0x33, /* service id */
+        0xBC, 0xBB, 0x8B, 0x4F,
+        0xB6, 0xB0, 0x13, 0x3E,
+        0xC2, 0xAA, 0xE6, 0xDF,
+        0x08, 0x00, 0x00, 0x00, /* command id */
+        0x00, 0x00, 0x00, 0x00, /* status code */
+        0x84, 0x00, 0x00, 0x00, /* buffer length */
+        /* information buffer */
+        0x02, 0x00, 0x00, 0x00, /* 0x00 providers count */
+        0x14, 0x00, 0x00, 0x00, /* 0x04 provider 0 offset */
+        0x38, 0x00, 0x00, 0x00, /* 0x08 provider 0 length */
+        0x4C, 0x00, 0x00, 0x00, /* 0x0C provider 1 offset */
+        0x38, 0x00, 0x00, 0x00, /* 0x10 provider 1 length */
+        /* data buffer... struct provider 0 */
+        0x20, 0x00, 0x00, 0x80, /* 0x14 [0x00] id offset */     /* OFFSET WRONG (0x80 instead of 0x00) */
+        0x0A, 0x00, 0x00, 0x80, /* 0x18 [0x04] id length */     /* LENGTH WRONG (0x80 instead of 0x00) */
+        0x08, 0x00, 0x00, 0x00, /* 0x1C [0x08] state */
+        0x2C, 0x00, 0x00, 0x00, /* 0x20 [0x0C] name offset */
+        0x0C, 0x00, 0x00, 0x00, /* 0x24 [0x10] name length */
+        0x01, 0x00, 0x00, 0x00, /* 0x28 [0x14] cellular class */
+        0x0B, 0x00, 0x00, 0x00, /* 0x2C [0x18] rssi */
+        0x00, 0x00, 0x00, 0x00, /* 0x30 [0x1C] error rate */
+        0x32, 0x00, 0x31, 0x00, /* 0x34 [0x20] id string (10 bytes) */
+        0x34, 0x00, 0x30, 0x00,
+        0x33, 0x00, 0x00, 0x00,
+        0x4F, 0x00, 0x72, 0x00, /* 0x40 [0x2C] name string (12 bytes) */
+        0x61, 0x00, 0x6E, 0x00,
+        0x67, 0x00, 0x65, 0x00,
+        /* data buffer... struct provider 1 */
+        0x20, 0x00, 0x00, 0x00, /* 0x4C [0x00] id offset */
+        0x0A, 0x00, 0x00, 0x00, /* 0x50 [0x04] id length */
+        0x19, 0x00, 0x00, 0x00, /* 0x51 [0x08] state */
+        0x2C, 0x00, 0x00, 0x00, /* 0x54 [0x0C] name offset */
+        0x0C, 0x00, 0x00, 0x00, /* 0x58 [0x10] name length */
+        0x01, 0x00, 0x00, 0x00, /* 0x5C [0x14] cellular class */
+        0x0B, 0x00, 0x00, 0x00, /* 0x60 [0x18] rssi */
+        0x00, 0x00, 0x00, 0x00, /* 0x64 [0x1C] error rate */
+        0x32, 0x00, 0x31, 0x00, /* 0x68 [0x20] id string (10 bytes) */
+        0x34, 0x00, 0x30, 0x00,
+        0x33, 0x00, 0x00, 0x00,
+        0x4F, 0x00, 0x72, 0x00, /* 0x74 [0x2C] name string (12 bytes) */
+        0x61, 0x00, 0x6E, 0x00,
+        0x67, 0x00, 0x65, 0x00 };
+
+    response = mbim_message_new (buffer, sizeof (buffer));
+
+    result = mbim_message_visible_providers_response_parse (response,
+                                                            &n_providers,
+                                                            &providers,
+                                                            &error);
+
+    g_assert (error != NULL);
+    g_assert (!result);
+}
+
 int main (int argc, char **argv)
 {
     g_test_init (&argc, &argv, NULL);
@@ -1808,6 +1881,7 @@ int main (int argc, char **argv)
     g_test_add_func ("/libmbim-glib/message/parser/basic-connect/ip-packet-filters/two", test_message_parser_basic_connect_ip_packet_filters_two);
     g_test_add_func ("/libmbim-glib/message/parser/ms-firmware-id/get", test_message_parser_ms_firmware_id_get);
     g_test_add_func ("/libmbim-glib/message/parser/basic-connect/connect/short", test_message_parser_basic_connect_connect_short);
+    g_test_add_func ("/libmbim-glib/message/parser/basic-connect/visible-providers/overflow", test_message_parser_basic_connect_visible_providers_overflow);
 
     return g_test_run ();
 }
